@@ -87,13 +87,16 @@ class XML(object):
         ugly_xml = etree.tostring(self.root, encoding="UTF-8")
         # Split string on adjacent tags without string in between
         stringlines = ">\n<".join(ugly_xml.split("><")).split("\n")
+        # Remove xml version encoding that is inserted if using xml, not lxml
+        if stringlines[0].startswith("<?xml"):
+            stringlines = stringlines[1:]
         indent = 0
         string = ('<?xml version="1.0" encoding="UTF-8" standalone="yes"?>\n' +
                   stringlines[0] + "\n")
 
         for number, line in enumerate(stringlines[1:]):
             # Line starts with closing tag
-            if line.startswith("</"):
+            if line.strip().startswith("</"):
                 indent -= 2
             # Line opens and closes tag
             elif ("</" in stringlines[number] and not
@@ -106,7 +109,7 @@ class XML(object):
         return string
 
     def __repr__(self):
-        return 'XML("{}")'.format(self.source_file)
+        return '{}("{}")'.format(self.__class__.__name__, self.source_file)
 
     def __getattr__(self, key):
         """
